BufRand

Struct BufRand 

pub struct BufRand<R: RngCore> {
    pub rand: R,
    /* private fields */
}
used to generate random booleans using a bit buffer

Fields

rand: R

the inner randomizer of this BufRand. this is pub so it can be used after this BufRand has been Constructed

Implementations

Source

impl<R: RngCore> BufRand<R>

pub fn new(rand: R) -> Self

create a new BufRand which generates random booleans using the supplied rng

Examples found in repository?
examples/random_bool.rs (line 4)
3fn main() {
4    let mut rand = BufRand::new(rand::thread_rng());
5    println!("{}", rand.next_bool());
6}
More examples
Hide additional examples
examples/random_case.rs (line 4)
3fn main() {
4    let mut rand = BufRand::new(rand::thread_rng());
5    println!("{}", rand.rand_string_case("Hello World!"));
6}
examples/inner_randomizer.rs (line 5)
4fn main() {
5    let mut buf_rand = BufRand::new(rand::thread_rng());
6    // the inner randomizer (rand) of buf_rand can still be used
7    buf_rand.rand.next_u32();
8}
pub fn next_bool(&mut self) -> bool

returns a random boolean from the buffer of this BufRand

use buf_rand::BufRand;

let mut rand = BufRand::new(rand::thread_rng());
rand.next_bool();
Examples found in repository?
examples/random_bool.rs (line 5)
3fn main() {
4    let mut rand = BufRand::new(rand::thread_rng());
5    println!("{}", rand.next_bool());
6}
pub fn rand_char_case(&mut self, c: &char) -> String

randomizes the capitalization of a char this returns a String since some chars may result in multiple when the case is changed such as this

// example of character turning into multiple
assert_eq!('ß'.to_uppercase().to_string(), "SS");
use buf_rand::BufRand;

let mut rand = BufRand::new(rand::thread_rng());
rand.rand_char_case(&'E');
pub fn rand_string_case(&mut self, s: &str) -> String

randomizes the capitalization of every character in the string

use buf_rand::BufRand;

let mut rand = BufRand::new(rand::thread_rng());
rand.rand_string_case("hello world!");
Examples found in repository?
examples/random_case.rs (line 5)
3fn main() {
4    let mut rand = BufRand::new(rand::thread_rng());
5    println!("{}", rand.rand_string_case("Hello World!"));
6}