[−][src]Struct buf_rand::BufRand
used to generate random booleans using a bit buffer
Implementations
impl<R: RngCore> BufRand<R>[src]
pub fn new(rand: R) -> Self[src]
create a new BufRand which generates random booleans using the supplied rng
pub fn next_bool(&mut self) -> bool[src]
returns a random boolean from the buffer of this BufRand
use buf_rand::BufRand; let mut rand = BufRand::new(Box::new(rand::thread_rng())); rand.next_bool();
pub fn rand_char_case(&mut self, c: &char) -> String[src]
randomizes the capitalization of a char
this returns a String since some chars may result in multiple when the case is changed
such as this
//example of character turning into multiple assert_eq!('ß'.to_uppercase().to_string(), "SS"); use buf_rand::BufRand; let mut rand = BufRand::new(Box::new(rand::thread_rng())); rand.rand_char_case(&'E');
pub fn rand_string_case(&mut self, s: &str) -> String[src]
randomizes the capitalization of every character in the string
use buf_rand::BufRand; let mut rand = BufRand::new(Box::new(rand::thread_rng())); rand.rand_string_case("hello world!");