[−][src]Struct buf_rand::BufRand
used to generate random booleans using a bit buffer
Implementations
impl BufRand[src]
pub fn new(rand: Box<dyn RngCore>) -> Self[src]
create a new BufRand which generates random booleans using the supplied rng
pub fn next_bool(&mut self) -> bool[src]
returns a random boolean from the buffer of this BufRand
pub fn rand_char_case(&mut self, c: &char) -> Option<char>[src]
randomizes the capitalization of a char
returns None in case the changed character is empty
pub fn rand_string_case(&mut self, s: &str) -> String[src]
randomizes the capitalization of every character in the string
Methods from Deref<Target = Box<dyn RngCore>>